#
# spec file for package saphanabootstrap-formula
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           saphanabootstrap-formula
Version:        0.2.9
Release:        lp151.7.1
Summary:        SAP HANA platform deployment formula
License:        Apache-2.0

Url:            https://github.com/SUSE/%{name}
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       habootstrap-formula
Requires:       salt-shaptools
Suggests:       hanadb_exporter >= 0.3.1

# TODO: Include this dependency back when is it available on 15-SP1.
# On SLE/Leap 15-SP1 and TW requires the new salt-formula configuration location.
#%if ! (0%{?sle_version:1} && 0%{?sle_version} < 150100)
#Requires:       salt-formulas-configuration
#%endif

%define fname hana
%define fdir  %{_datadir}/salt-formulas
%define ftemplates templates

%description
SAP HANA deployment salt formula. This formula is capable to install
SAP HANA nodes, enable system replication and configure SLE-HA cluster
with the SAPHanaSR resource agent, using standalone salt or via SUSE Manager
formulas with forms, available on SUSE Manager 4.0.

%if ! (0%{?sle_version:1} && 0%{?sle_version} < 150100)
The formula is installed on the /usr/share/salt-formulas location, so in order
to use it, make sure to map this directory into the file_roots of your
salt master/minion salt standalone configuration or into the SUSE Manager
salt configuration file (when using SUSE Manager formulas with forms).
%endif

%prep
%setup -q

%build

%install

# before SUMA 4.0/15-SP1, install on the standard Salt Location.
%if 0%{?sle_version:1} && 0%{?sle_version} < 150100

mkdir -p %{buildroot}/srv/salt/
cp -R %{fname} %{buildroot}/srv/salt/
cp -R %{ftemplates} %{buildroot}/srv/salt/%{fname}/

%else

# On SUMA 4.0/15-SP1, a single shared directory will be used.
mkdir -p %{buildroot}%{fdir}/states/%{fname}
mkdir -p %{buildroot}%{fdir}/metadata/%{fname}
cp -R %{fname} %{buildroot}%{fdir}/states
cp -R %{ftemplates} %{buildroot}%{fdir}/states/%{fname}
cp -R form.yml %{buildroot}%{fdir}/metadata/%{fname}
if [ -f metadata.yml ]
then
  cp -R metadata.yml %{buildroot}%{fdir}/metadata/%{fname}
fi

%endif

%if 0%{?sle_version:1} && 0%{?sle_version} < 150100
%files
%defattr(-,root,root,-)
%if 0%{?sle_version} < 120300
%doc README.md LICENSE
%else
%doc README.md
%license LICENSE
%endif
/srv/salt/%{fname}
/srv/salt/%{fname}/%{ftemplates}

%dir %attr(0755, root, salt) /srv/salt

%else

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%dir %{fdir}
%dir %{fdir}/states
%dir %{fdir}/metadata
%{fdir}/states/%{fname}
%{fdir}/states/%{fname}/%{ftemplates}
%{fdir}/metadata/%{fname}

%dir %attr(-, root, root) %{fdir}
%dir %attr(-, root, root) %{fdir}/states
%dir %attr(-, root, root) %{fdir}/metadata

%endif

%changelog
* Wed Aug  7 2019 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.2.9
  * Fix srHook script usage for cost optimized scenario
  * Add scenario type options to the form.yml file
    (boo#1137989)
* Wed Jul 31 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Fix errors in the form.yml file to match with the formula names
- Fix some styling issues
* Tue Jul 23 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.8
  * Add support for Power machines
  * Fix issues with SAP HANA deployment template and the exporter
* Mon Jul 22 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.7
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas
    (boo#1142306)
* Mon Jul  8 2019 Dario Maiocchi <dmaiocchi@suse.com>
- Version bump 0.2.6
  * Retry pkg.install multiple times, in case a pkg installtion fails
  for having a more resilient installation.
* Wed Jul  3 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.5
  * hanadb_exporter executed as a daemon
  * hanadb_exporter installation suggested
* Tue Jul  2 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.4
  * Change the salt-formula directories permissions to 0750 to avoid
    conflicts with the package salt-standalone-formulas-configuration.
  * Correct the required package name to
    salt-standalone-formulas-configuration
* Mon Jul  1 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.3 supporting hanadb_exporter logging system
* Wed Jun 19 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.2 adding hanadb_exporter deployment
* Tue Jun 11 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.1 with fixed spec files. Now the package
  is available in all SLE12 and SLE15 versions (boo#1137989, jsc#SLE-4143)
* Thu Jun  6 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Fix how qas instance number is created in scale_up_resources template
* Tue May 21 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.0
  * Include the salt-formulas-configuration dependency on
    SLE/Leap 15-SP1 and higher. This package configures the shared salt
    formulas location (/usr/share/salt-formulas) to be used by SUMA 4.0
    or salt in standalone mode.
  * Drops the saphanabootstrap-formula-suma package, as the forms metadata
    will be available only on SUMA 4.0 using the shared location.
* Thu May 16 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update formula to work with the latest shaptools code. In this version
  the secondary node registration is managed completely in shaptools
* Thu Apr 25 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Changed requires from salt-saphana to salt-shaptools.
* Mon Mar 18 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update primary available checking to execute this action before
  trying to copy the SSFS files from primary node
- Add configurable timeout to wait to the primary node
* Tue Mar 12 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Fix OS release comparison to use integer type in order to choose
  installable python version
* Fri Mar  8 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Improve shaptools installation python version management
* Mon Mar  4 2019 xarbulu@suse.com
- Improved the use of keystore access. When the key_name is informed,
  the user_name/user_password is not needed.
* Mon Feb 25 2019 dakechi@suse.com
- Forces lower case SID when composing the OS username
- Typos fixing.
- Adjust the labels to SAP terminology and include help texts.
* Wed Feb 20 2019 xarbulu@suse.com
- Add templates folder with RA configuration templates
* Thu Dec 20 2018 xarbulu@suse.com
- First version of the SAP HANA deployment formula
